@@ -5,7 +5,17 @@ def main2(*args,**kwargs):
     client = SocketClient(cb=LocalEchoHTTPClient)
     client.connect(kwargs['domain'],kwargs['port'])
 
+def delim_period(**kwargs):
+    def new_conn(conn):
+        EchoConnection(conn, '.')
+    server = SocketDaemon(kwargs['domain'], kwargs['port'], new_conn)
+    server.start()
+
 def main(**kwargs):
+    server = SocketDaemon(kwargs['domain'], kwargs['port'], cb=EchoChunked)
+    server.start()
+
+def delim_linebreak(**kwargs):
     server = SocketDaemon(kwargs['domain'], kwargs['port'], cb=EchoConnection)
     server.start()
 
@@ -13,6 +23,26 @@ def http(**kwargs):
     server = SocketDaemon(kwargs['domain'], kwargs['port'],cb=EchoHTTP)
     server.start()
 
+class EchoChunked(object):
+    def __init__(self, conn):
+        self.conn = conn
+        self.conn.set_rmode_close_chunked(self._recv)
+
+    def _recv(self, data):
+        print 'received:',data
+        self.conn.write(data)
+
+class EchoConnection(object):
+    def __init__(self, conn, delim='\r\n'):
+        self.delim = delim
+        self.conn = conn
+        self.conn.set_rmode_delimiter(self.delim, self.line_received)
+
+    def line_received(self, data):
+        self.conn.write("S: " + data + self.delim)
+        print data
+        #self.conn.set_rmode_close(self.line_received)
+
 class LocalEchoHTTPClient(object):
     def __init__(self, conn):
         self.conn = conn
@@ -28,17 +58,7 @@ class LocalEchoHTTPClient(object):
             
     def body(self, data):
         print data
-        sys.exit(0);
-
-class EchoConnection(object):
-    def __init__(self, conn):
-        self.conn = conn
-        self.conn.set_rmode_delimiter('\r\n', self.line_received)
-
-    def line_received(self, data):
-        #self.conn.write("S: " + data + '\r\n')
-        print data
-        self.conn.set_rmode_close(self.line_received)
+        sys.exit(0)
 
 class EchoHTTP(object):
     def __init__(self, conn):
